@@ -176,6 +176,11 @@ def getFileExtName(file):
     return file[file.rfind('.') + 1:].lower()
 
 
+def getFileBaseName(file):
+    fileName = os.path.basename(file)
+    return fileName[:fileName.rfind(".")]
+
+
 def getFileList(folder):
     ary = []
     for targetName in os.listdir(folder):
