@@ -104,5 +104,5 @@ def isDev():
 
 def create(targetPath):
     currentFolder = os.path.dirname(__file__)
-    taskZipfile = b.getPath(currentFolder, "data/task.dat")
+    taskZipfile = b.getPath(currentFolder, "data/task.zip")
     b.zipFileExtract(taskZipfile, targetPath)
